oceanum.datamesh package
========================

Submodules
----------

oceanum.datamesh.catalog module
-------------------------------

.. automodule:: oceanum.datamesh.catalog
   :members:
   :undoc-members:

oceanum.datamesh.connection module
----------------------------------

.. automodule:: oceanum.datamesh.connection
   :members:
   :undoc-members:
   :show-inheritance:

oceanum.datamesh.datasource module
----------------------------------

.. .. automodule:: oceanum.datamesh.datasource
..    :members:
..    :undoc-members:
..    :show-inheritance:
.. autopydantic_model:: oceanum.datamesh.datasource.Datasource
   :model-show-json: True
   :model-show-config-summary: False


oceanum.datamesh.query module
-----------------------------

.. automodule:: oceanum.datamesh.query
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: oceanum.datamesh
   :members:
   :undoc-members:
   :show-inheritance:
